summaryrefslogtreecommitdiff
path: root/ports/nrf/common-hal/microcontroller/Pin.h
diff options
context:
space:
mode:
authorDan Halbert <halbert@halwitz.org>2018-08-31 17:46:03 -0400
committerDan Halbert <halbert@halwitz.org>2018-08-31 18:38:05 -0400
commit9ea809bef73e6862103cd71802803122e97bf80b (patch)
treefd918c0aec0e93abdefbff69052349446e15e0cc /ports/nrf/common-hal/microcontroller/Pin.h
parent585597a252be431fd4efe11a9120329b233ebba5 (diff)
add pin claiming to devices
Diffstat (limited to 'ports/nrf/common-hal/microcontroller/Pin.h')
-rw-r--r--ports/nrf/common-hal/microcontroller/Pin.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/ports/nrf/common-hal/microcontroller/Pin.h b/ports/nrf/common-hal/microcontroller/Pin.h
index 1e751c714..2cdf440b5 100644
--- a/ports/nrf/common-hal/microcontroller/Pin.h
+++ b/ports/nrf/common-hal/microcontroller/Pin.h
@@ -40,9 +40,9 @@ extern bool apa102_mosi_in_use;
#endif
void reset_all_pins(void);
// reset_pin takes the pin number instead of the pointer so that objects don't
// need to store a full pointer.
-void reset_pin(uint8_t pin);
+void reset_pin_number(uint8_t pin);
void claim_pin(const mcu_pin_obj_t* pin);
// Lower 5 bits of a pin number are the pin number in a port.
@@ -40,9 +40,9 @@ extern bool apa102_mosi_in_use;
#endif
void reset_all_pins(void);
-// reset_pin takes the pin number instead of the pointer so that objects don't
+// reset_pin_number takes the pin number instead of the pointer so that objects don't
// need to store a full pointer.